function [xbar,s,Ta,T0] = htestmu1(altype,alpha,mu0,x,s,sigma,n)

//Hypothesis testing on one mean.  Possible function calls:
//
// [xbar,s,Ta,T0] = htestmu1(altype,alpha,mu0,xbar,s,sigma,n)
// [xbar,s,Ta,T0] = htestmu1(altype,alpha,mu0,x,sigma)
//
// altype can be 'one' - for one-sided alternative hypothesis, 
// or 'two' - for two sided alternative hypothesis
// alpha = level of significance (typical values = 0.01,0.05,0.10)
// mu0   = value of population mean being tested, H0:mu = mu0
// x     = mean value of a sample (xbar) or vector representing the sample
// if x  = mean value, then s = standard deviation of sample
// if x  = vector representing sample, s = standard deviation of population
// if x  = mean value, sigma = standard deviation of population and
//    n  = sample size

if altype<>'one' & altype<>'two' then
   error('htestmu1 - select type of alternative hypothesis = one or two');
   abort;
end;

[nargout,nargin] = argn(0)

if nargin == 5 then 
   if length(x)<1 then
      error('htestmu1 - x must be a vector');
      abort;
   else
      sigma = s;
      n     = length(x);
      xbar  = mean(x);
      s     = st_deviation(x);
   end;
else
   xbar = x; 
end;

printf(' \n');
printf('Hypothesis testing on one mean: ' ...
       + altype + '-side alternative hypothesis.\n')
printf(' \n');

if sigma > 0 & altype=='one' then
   Ta = cdfnor('X',0,1,1-alpha,alpha);
   T0 = (xbar-mu0)/(sigma/sqrt(n));
   printf('Test parameter used: z');
elseif sigma >0 & altype=='two' then
   Ta = cdfnor('X',0,1,1-alpha/2,alpha/2);
   T0 = (xbar-mu0)/(sigma/sqrt(n));
   printf('Test parameter used: z');
elseif sigma <=0 & n>=30 & altype=='one' then
   Ta = cdfnor('X',0,1,1-alpha,alpha);
   T0 = (xbar-mu0)/(s/sqrt(n));
   printf('Test parameter used: z');
elseif sigma <=0 & n<30 & altype=='one' then
   Ta = cdft('T',n-1,1-alpha,alpha);
   T0 = (xbar-mu0)/(s/sqrt(n));
   printf('Test parameter used: t');
elseif sigma <=0 & n>=30 & altype=='two' then
   Ta = cdfnor('X',0,1,1-alpha/2,alpha/2);
   T0 = (xbar-mu0)/(s/sqrt(n));
   printf('Test parameter used: z');
else
   Ta = cdft('T',n-1,1-alpha/2,alpha/2);
   T0 = (xbar-mu0)/(s/sqrt(n));
   printf('Test parameter used: t');
end;

if altype == 'two' then
   if T0>Ta | T0<-Ta then
      printf('Reject the null hypothesis H0 : mu = %f\n',mu0);
   else
      printf('Do not reject the null hypothesis H0 : mu = %f\n',mu0);
   end
else
  if T0>Ta then
     printf('Reject the null hypothesis H0 : mu = %f\n',mu0);
     printf('if the alternative hypothesis is H1 : mu > %f\n',mu0);
  elseif T0<-Ta
     printf('Reject the null hypothesis H0 : mu = %f\n',mu0);
     printf('if the alternative hypothesis is H1 : mu < %f\n',mu0);
  else
     printf('Do not reject the null hypothesis H0 : mu = %f\n',mu0);
  end
end;
printf(' \n');
endfunction